<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Eltávolítás a Dokkolóról</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Kitűzés a Dokkra</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Kényszerített kilépés</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Összes bezárása</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation type="unfinished">Megnyitás</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation type="unfinished">Eltávolítás a Dokkolóról</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation type="unfinished">Kitűzés a Dokkra</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation type="unfinished">Kényszerített kilépés</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation type="unfinished">Összes bezárása</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
